@@ -443,14 +443,10 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
         }
         else
         {
-            runAsSubject(new PrivilegedAction<Object>()
+            runAsSubject(() ->
             {
-                @Override
-                public Object run()
-                {
-                    performDeleteTasks();
-                    return null;
-                }
+                performDeleteTasks();
+                return null;
             });
         }
     }
@@ -542,23 +538,18 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
         {
             final SettableFuture<Void> future = SettableFuture.create();
 
-            addAsyncTask(
-                    new Action<Object>()
-                    {
-                        @Override
-                        public void performAction(final Object object)
-                        {
-                            try
-                            {
-                                task.run();
-                                future.set(null);
-                            }
-                            catch (RuntimeException e)
-                            {
-                                future.setException(e);
-                            }
-                        }
-                    });
+            addAsyncTask(object ->
+            {
+                try
+                {
+                    task.run();
+                    future.set(null);
+                }
+                catch (RuntimeException e)
+                {
+                    future.setException(e);
+                }
+            });
             return future;
         }
     }
@@ -776,50 +767,42 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
 
     private void logConnectionOpen()
     {
-        runAsSubject(new PrivilegedAction<Object>()
+        runAsSubject(() ->
         {
-            @Override
-            public Object run()
+            SocketAddress localAddress = _network.getLocalAddress();
+            final String localAddressStr;
+            if (localAddress instanceof InetSocketAddress)
             {
-                SocketAddress localAddress = _network.getLocalAddress();
-                final String localAddressStr;
-                if (localAddress instanceof InetSocketAddress)
-                {
-                    InetSocketAddress inetAddress = (InetSocketAddress) localAddress;
-                    localAddressStr = inetAddress.getAddress().getHostAddress() + ":" + inetAddress.getPort();
-                }
-                else
-                {
-                    localAddressStr = localAddress.toString();
-                }
-                getEventLogger().message(ConnectionMessages.OPEN(getPort().getName(),
-                                                                 localAddressStr,
-                                                                 getProtocol().getProtocolVersion(),
-                                                                 getClientId(),
-                                                                 getClientVersion(),
-                                                                 getClientProduct(),
-                                                                 getTransport().isSecure(),
-                                                                 getClientId() != null,
-                                                                 getClientVersion() != null,
-                                                                 getClientProduct() != null));
-                return null;
+                InetSocketAddress inetAddress = (InetSocketAddress) localAddress;
+                localAddressStr = inetAddress.getAddress().getHostAddress() + ":" + inetAddress.getPort();
             }
+            else
+            {
+                localAddressStr = localAddress.toString();
+            }
+            getEventLogger().message(ConnectionMessages.OPEN(getPort().getName(),
+                                                             localAddressStr,
+                                                             getProtocol().getProtocolVersion(),
+                                                             getClientId(),
+                                                             getClientVersion(),
+                                                             getClientProduct(),
+                                                             getTransport().isSecure(),
+                                                             getClientId() != null,
+                                                             getClientVersion() != null,
+                                                             getClientProduct() != null));
+            return null;
         });
     }
 
     private void logConnectionClose()
     {
-        runAsSubject(new PrivilegedAction<Void>()
+        runAsSubject((PrivilegedAction<Void>) () ->
         {
-            @Override
-            public Void run()
-            {
-                String closeCause = getCloseCause();
-                getEventLogger().message(isOrderlyClose()
-                                                 ? ConnectionMessages.CLOSE(closeCause, closeCause != null)
-                                                 : ConnectionMessages.DROPPED_CONNECTION());
-                return null;
-            }
+            String closeCause = getCloseCause();
+            getEventLogger().message(isOrderlyClose()
+                                             ? ConnectionMessages.CLOSE(closeCause, closeCause != null)
+                                             : ConnectionMessages.DROPPED_CONNECTION());
+            return null;
         });
     }
 
